@@ -21,6 +21,7 @@
 #ifndef XAPIAN_INCLUDED_PARSEINT_H
 #define XAPIAN_INCLUDED_PARSEINT_H
 
+#include "negate_unsigned.h"
 #include "overflow.h"
 #include <limits>
 
@@ -42,12 +43,12 @@ bool parse_unsigned(const char* p, T& res)
 template<typename T>
 bool parse_signed(const char* p, T& res)
 {
-    typedef typename std::make_unsigned<T>::type unsigned_type;
+    typedef typename std::make_unsigned_t<T> unsigned_type;
     unsigned_type temp = 0;
     if (*p == '-' && parse_unsigned(++p, temp) &&
 	// casting the min signed value to unsigned gives us its absolute value.
 	temp <= unsigned_type(std::numeric_limits<T>::min())) {
-	res = -temp;
+	res = negate_unsigned(temp);
 	return true;
     } else if (parse_unsigned(p, temp) &&
 	       temp <= unsigned_type(std::numeric_limits<T>::max())) {
