@@ -22,9 +22,10 @@
 
 #include "str.h"
 
+#include "negate_unsigned.h"
 #include "omassert.h"
 
-#include <cstdio> // For snprintf() or sprintf().
+#include <cstdio> // For snprintf().
 #include <cstdlib> // For abort().
 #include <string>
 #include <type_traits>
@@ -36,7 +37,7 @@ template<class T>
 static inline string
 tostring_unsigned(T value)
 {
-    static_assert(std::is_unsigned<T>::value, "Unsigned type required");
+    static_assert(std::is_unsigned_v<T>, "Unsigned type required");
     // Special case single digit positive numbers.
     // FIXME: is this actually worthwhile?
     if (value < 10) return string(1, '0' + char(value));
@@ -61,10 +62,10 @@ tostring(T value)
 
     bool negative = (value < 0);
 
-    typedef typename std::make_unsigned<T>::type unsigned_type;
+    typedef typename std::make_unsigned_t<T> unsigned_type;
     unsigned_type val(value);
     if (negative) {
-	val = -val;
+	val = negate_unsigned(val);
     }
 
     char buf[(sizeof(unsigned_type) * 5 + 1) / 2 + 1];
@@ -127,17 +128,11 @@ static inline string
 format(const char * fmt, T value)
 {
     char buf[128];
-#ifdef SNPRINTF
     // If -1 is returned (as pre-ISO snprintf does if the buffer is too small,
     // it will be cast to > sizeof(buf) and handled appropriately.
-    size_t size = SNPRINTF(buf, sizeof(buf), fmt, value);
+    size_t size = snprintf(buf, sizeof(buf), fmt, value);
     AssertRel(size,<=,sizeof(buf));
     if (size > sizeof(buf)) size = sizeof(buf);
-#else
-    size_t size = sprintf(buf, fmt, value);
-    // Buffer overflow.
-    if (size >= sizeof(buf)) abort();
-#endif
     return string(buf, size);
 }
 
